Security Advisories (6)
CVE-2017-10788 (2017-04-13)

The DBD::mysql module through 4.043 for Perl allows remote attackers to cause a denial of service (use-after-free and application crash) or possibly have unspecified other impact by triggering (1) certain error responses from a MySQL server or (2) a loss of a network connection to a MySQL server. The use-after-free defect was introduced by relying on incorrect Oracle mysql_stmt_close documentation and code examples.

CVE-2017-10789 (2017-03-23)

The DBD::mysql module through 4.043 for Perl uses the mysql_ssl=1 setting to mean that SSL is optional (even though this setting's documentation has a "your communication with the server will be encrypted" statement), which allows man-in-the-middle attackers to spoof servers via a cleartext-downgrade attack, a related issue to CVE-2015-3152.

CVE-2016-1249 (2016-11-16)

Out-of-bounds read.

CVE-2016-1246 (2016-10-02)

Buffer overflow in the DBD::mysql module before 4.037 for Perl allows context-dependent attackers to cause a denial of service (crash) via vectors related to an error message.

CVE-2015-8949 (2016-08-19)

Use-after-free vulnerability in the my_login function in DBD::mysql before 4.033_01 allows attackers to have unspecified impact by leveraging a call to mysql_errno after a failure of my_login.

CVE-2016-1251 (2015-12-27)

There is a vulnerability of type use-after-free affecting DBD::mysql (aka DBD-mysql or the Database Interface (DBI) MySQL driver for Perl) 3.x and 4.x before 4.041 when used with mysql_server_prepare=1.

DBD::mysql - database driver for Perl

This is the Perl DBI driver for access to MySQL databases.

Usage

Usage is described in DBD::mysql.

Installation

Installation is described in DBD::mysql::INSTALL.

Support

The driver is maintained by a mailing list:

This module is maintained and supported on a mailing list, dbi-users. To subscribe to this list, send an email to

dbi-users-subscribe@perl.org

Mailing list archives are at

http://groups.google.com/group/perl.dbi.users

You can also get help from the maintainer, Patrick Galbraith patg@patg.net